pub struct LogDbBuilder { /* private fields */ }Expand description
Builder for creating LogDb instances with custom options.
This builder provides a fluent API for configuring a LogDb, including runtime options that cannot be serialized in configuration files.
Example
use log::LogDbBuilder;
use log::Config;
use common::StorageRuntime;
// Create a separate runtime for compaction (important for sync/JNI usage)
let compaction_runtime = tokio::runtime::Builder::new_multi_thread()
.worker_threads(2)
.enable_all()
.build()
.unwrap();
let runtime = StorageRuntime::new()
.with_compaction_runtime(compaction_runtime.handle().clone());
let log = LogDbBuilder::new(config)
.with_storage_runtime(runtime)
.build()
.await?;Implementations
Sourceimpl LogDbBuilder
impl LogDbBuilder
Sourcepub fn with_storage_runtime(self, runtime: StorageRuntime) -> Self
pub fn with_storage_runtime(self, runtime: StorageRuntime) -> Self
Sets the storage runtime options.
Use this to configure runtime options like the compaction runtime handle.