Struct Metadata

pub struct Metadata<'a> { /* private fields */ }

Metadata about a log message.

Use

Metadata structs are created when users of the library use logging macros.

They are consumed by implementations of the Log trait in the enabled method.

Records use Metadata to determine the log message's severity and target.

Users should use the log_enabled! macro in their code to avoid constructing expensive log messages.

Examples

use log::{Record, Level, Metadata};

struct MyLogger;

impl log::Log for MyLogger {
    fn enabled(&self, metadata: &Metadata) -> bool {
        metadata.level() <= Level::Info
    }

    fn log(&self, record: &Record) {
        if self.enabled(record.metadata()) {
            println!("{} - {}", record.level(), record.args());
        }
    }
    fn flush(&self) {}
}

# fn main(){}

Implementations

impl<'a> Metadata<'a>

fn builder() -> MetadataBuilder<'a>

Returns a new builder.

fn level(&self) -> Level

The verbosity level of the message.

fn target(&self) -> &'a str

The name of the target of the directive.